@@ -165,13 +165,14 @@ void DCChat::InitDocument()
 	m_pTextEdit_CHATOUTPUT->setMinimumSize( QSize( 0, 60 ) );
 	m_pTextEdit_CHATOUTPUT->setTextFormat( QTextEdit::RichText );
 	m_pTextEdit_CHATOUTPUT->setWordWrap( QTextEdit::WidgetWidth );
-	m_pTextEdit_CHATOUTPUT->setWrapPolicy( QTextEdit::AtWhiteSpace );
+	m_pTextEdit_CHATOUTPUT->setWrapPolicy( QTextEdit::AtWordOrDocumentBoundary );
     	m_pTextEdit_CHATOUTPUT->setReadOnly( TRUE );
 	Frame_OUTPUTLayout->addWidget(m_pTextEdit_CHATOUTPUT,0,0);
 
 	connect( m_pTextEdit_CHATOUTPUT, SIGNAL(rightButtonClicked( const QPoint& )), this, SLOT(slotRightButtonClickedChatOutput( const QPoint& )) );
 #if QT_VERSION >= 0x030100
 	connect( m_pTextEdit_CHATOUTPUT, SIGNAL(clicked( int, int )), this, SLOT(slotClickedChatOutput( int, int )) );
+	connect( m_pTextEdit_CHATOUTPUT, SIGNAL(doubleClicked( int, int )), this, SLOT(slotDoubleClickedChatOutput( int, int )) );
 #endif
 	if ( PushButton_SEND )
 	{
@@ -773,7 +774,15 @@ void DCChat::slotRightButtonClickedChatOutput( const QPoint& )
 					if ( ((EmoticonObject->left<x) && (EmoticonObject->right>x)) &&
 					     ((EmoticonObject->top<y)  && (EmoticonObject->bottom>y)) )
 					{
-						TextEdit_CHATINPUT->insert(EmoticonObject->m_Text.Data());
+						// damn hacks
+						QString smiley = EmoticonObject->m_Text.Data();
+						smiley = smiley.replace( "&lt;", "<" );
+						smiley = smiley.replace( "&gt;", ">" );
+						smiley = smiley.replace( "&amp;", "&" );
+						smiley = smiley.replace( "&apos;", "\'" );
+						smiley = smiley.replace( "&quot;", "\"" );
+						
+						TextEdit_CHATINPUT->insert(smiley);
 						break;
 					}
 				}
@@ -1014,11 +1023,11 @@ void DCChat::SetNick( CString nick, CString hubname )
 
 	if ( nick != "" )
 	{
-		setCaption(tr("Private Chat:")+" "+QString::fromUtf8(nick.Data())+" ["+QString::fromUtf8(hubname.Data())+"]");
+		setCaption(tr("Private Chat:")+" "+QString::fromAscii(nick.Data())+" ["+QString::fromAscii(hubname.Data())+"]");
 	}
 	else
 	{
-		setCaption(tr("Chat:")+" ["+QString::fromUtf8(hubname.Data())+"]");
+		setCaption(tr("Chat:")+" ["+QString::fromAscii(hubname.Data())+"]");
 	}
 }
 
@@ -1072,7 +1081,7 @@ void DCChat::AddOutput( CString message )
 		m_pTextEdit_CHATOUTPUT->removeParagraph(0);
 	}
 	
-	m_pTextEdit_CHATOUTPUT->append( QString::fromUtf8(message.Data()) );
+	m_pTextEdit_CHATOUTPUT->append( QString::fromAscii(message.Data()) );
 
 	if ( bscroll )
 	{
@@ -1199,6 +1208,15 @@ void DCChat::AddMessage( CString nick, CString message, bool bremote, bool forwa
 		return;
 	}
 
+	// check for nick - but avoid string searching if not enabled
+	if ( !m_bPrivateChat && g_pConfig->GetSoundEnabled(eusNICKMENTIONED) == TRUE )
+	{
+		if ( message.Find(m_pClient->GetNick()) != -1 )
+		{
+			g_pConfig->PlaySound(eusNICKMENTIONED);
+		}
+	}
+
 	// convert newline
 	message = message.Replace( "\\r\xa", "\xa" );
 	message = message.Replace( "\\r", "\xa" );
@@ -1676,6 +1694,8 @@ bool DCChat::CheckForCommand()
 			s += "\n";
 			s += tr("/unignore &lt;nick&gt - show main chat lines from the user again").ascii();
 			s += "\n";
+			s += tr("/ratio [show] - show share ratio [to other users]").ascii();
+			s += "\n";
 			AddStatus( s, TRUE );
 			res = TRUE;
 		}
@@ -2385,6 +2405,64 @@ bool DCChat::CheckForCommand()
 			AddStatus( s, TRUE );
 			res = TRUE;
 		}
+		else if ( cmd.Left(6) == "/ratio" )
+		{
+			ulonglong up = CSocket::m_Traffic.GetTraffic(ettTX);
+			ulonglong down = CSocket::m_Traffic.GetTraffic(ettRX);
+			
+			float ratio = 0;
+			
+			if ( down > 0 )
+			{
+				ratio = (double) up / (double) down;
+			}
+			
+			s  = tr("ratio: overall: ").ascii();
+			s += QString().setNum( ratio, 'f', 2 ).ascii();
+			s += " (";
+			s += tr("uploads").ascii();
+			s += ": ";
+			s += CUtils::GetSizeString( up, g_pConfig->GetUnit() );
+			s += " | ";
+			s += tr("downloads").ascii();
+			s += ": ";
+			s += CUtils::GetSizeString( down, g_pConfig->GetUnit() );
+			s += ")\n";
+			
+			up -= g_pConfig->GetStartUploaded();
+			down -= g_pConfig->GetStartDownloaded();
+			
+			if ( down > 0 )
+			{
+				ratio = (double) up / (double) down;
+			}
+			else
+			{
+				ratio = 0;
+			}
+			
+			s += tr("this session: ").ascii();
+			s += QString().setNum( ratio, 'f', 2 ).ascii();
+			s += " (";
+			s += tr("uploads").ascii();
+			s += ": ";
+			s += CUtils::GetSizeString( up, g_pConfig->GetUnit() );
+			s += " | ";
+			s += tr("downloads").ascii();
+			s += ": ";
+			s += CUtils::GetSizeString( down, g_pConfig->GetUnit() );
+			s += ")";
+			
+			if ( cmd.Mid( 7, 4 ).ToLower() == "show" )
+			{
+				SendMessage( s );
+			}
+			else
+			{
+				AddStatus( s, TRUE );
+			}
+			res = TRUE;
+		}
 	}
 	return res;
 }
@@ -2504,3 +2582,49 @@ void DCChat::NickCompletion()
 		}
 	}
 }
+
+/** insert double clicked word into chat input box */
+void DCChat::slotDoubleClickedChatOutput( int, int )
+{
+	// double clicking already selects the text
+	QString selected = m_pTextEdit_CHATOUTPUT->selectedText();
+	
+	// do noting on no selection
+	if ( selected == "" )
+	{
+		return;
+	}
+	
+	// remove all html tags
+	QRegExp re;
+	re.setMinimal(TRUE);
+	re.setPattern("<.*>");
+	selected = selected.replace( re, "" );
+	
+	// "NICK> " gets selected, trim "> " off nick
+	if ( selected.right(5) == "&gt; " )
+	{
+		selected = selected.left( selected.length() - 5 );
+	}
+	
+	// trim white space off ends
+	selected = selected.simplifyWhiteSpace();
+	
+	// add space on end
+	selected += " ";
+	
+	if ( TextEdit_CHATINPUT->text() == "" )
+	{
+		TextEdit_CHATINPUT->setText(selected);
+	}
+	else
+	{
+		if ( TextEdit_CHATINPUT->text().right(1) != " " )
+		{
+			selected = " " + selected;
+		}
+		
+		// not using TextEdit_CHATINPUT->append(), that would add a new line
+		TextEdit_CHATINPUT->setText( TextEdit_CHATINPUT->text() + selected );
+	}
+}
