@@ -19,7 +19,6 @@
 
 #include <qapplication.h>
 #include <qpainter.h>
-#include <qprinter.h>
 #include <qtextedit.h>
 #include <qlineedit.h>
 #include <qlistview.h>
@@ -28,7 +27,6 @@
 #include <qregexp.h>
 #include <qspinbox.h>
 #include <qcombobox.h>
-#include <qlcdnumber.h>
 #include <qpopupmenu.h>
 #include <qcursor.h>
 #include <qfile.h>
@@ -45,6 +43,7 @@
 #include <qsplitter.h>
 #include <qtoolbutton.h>
 #include <qtooltip.h>
+#include <qstringlist.h>
 
 #include <dcevent.h>
 #include <dchubsearch.h>
@@ -457,7 +456,7 @@ void DCClient::slotTabWidgetChatCurrentChange( QWidget * w )
 		TabWidget_CHAT->setTabIconSet( w, QIconSet() );
 		
 		// reset nick color
-		SetNickColor( QString::fromUtf8(chat->GetNick().Data()), ListView_USERLIST->colorGroup().text() );
+		SetNickColor( QString::fromAscii(chat->GetNick().Data()), ListView_USERLIST->colorGroup().text() );
 	}
 	
 	if (m_bUseTabWidget)
@@ -580,12 +579,12 @@ void DCClient::UpdateCaption()
 	}
 
 	s += " ";
-	s += QString::fromUtf8(GetHubName().Data());
+	s += QString::fromAscii(GetHubName().Data());
 
 	if ( GetHubTopic() != "" )
 	{
 		s += " (";
-		s += QString::fromUtf8(GetHubTopic().Data());
+		s += QString::fromAscii(GetHubTopic().Data());
 		s += ")";
 	}
 	
@@ -955,6 +954,21 @@ void DCClient::timerDone()
 				break;
 			}
 
+			case DC_MESSAGE_USERIP:
+			{
+				CMessageUserIP * msg = (CMessageUserIP*) Object;
+				
+				// fill in the IP address column for the given nick
+				QListViewItem * item = ListView_USERLIST->findItem( msg->m_sNick.Data(), 0 );
+				
+				if ( item != 0 )
+				{
+					item->setText( 6, msg->m_sIP.Data() );
+				}
+				
+				break;
+			}
+
 			default:
 			{
 				break;
@@ -1003,7 +1017,7 @@ void DCClient::DC_Chat( CMessageChat * MessageChat )
 	// check for ignored nick
 	if ( g_pUsersList->ignoreNick( MessageChat->m_sNick ) == TRUE )
 	{
-		printf("Ignoring \"%s\" from \"%s\"\n", MessageChat->m_sMessage.Data(), MessageChat->m_sNick.Data());
+		//printf("Ignoring \"%s\" from \"%s\"\n", MessageChat->m_sMessage.Data(), MessageChat->m_sNick.Data());
 		return;
 	}
 	
@@ -1040,9 +1054,9 @@ void DCClient::DC_MyInfo( CMessageMyInfo * MessageMyInfo )
 
 #ifndef WIN32
 		pm = *g_pConfig->GetUserIcon(MessageMyInfo->m_bOperator,MessageMyInfo->m_eClientMode,MessageMyInfo->m_eAwayMode,MessageMyInfo->m_eUserSpeed,MessageMyInfo->m_eClientVersion);
-		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8(MessageMyInfo->m_sNick.Data()), pm );
+		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii(MessageMyInfo->m_sNick.Data()), pm );
 #else
-		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8(MessageMyInfo->m_sNick.Data()) );
+		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii(MessageMyInfo->m_sNick.Data()) );
 #endif
 		// user not in the list, add it
 		addUser( MessageMyInfo->m_sNick.Data() );
@@ -1064,10 +1078,10 @@ void DCClient::DC_MyInfo( CMessageMyInfo * MessageMyInfo )
 
 	pui->MyInfo = *MessageMyInfo;
 
-	pui->pItem->setText(1,QString::fromUtf8(MessageMyInfo->m_sComment.Data()));
+	pui->pItem->setText(1,QString::fromAscii(MessageMyInfo->m_sComment.Data()));
 	pui->pItem->setText(2,MessageMyInfo->m_sVerComment.Data());
 	pui->pItem->setText(3,MessageMyInfo->m_sUserSpeed.Data());
-	pui->pItem->setText(4,QString::fromUtf8(MessageMyInfo->m_sEMail.Data()));
+	pui->pItem->setText(4,QString::fromAscii(MessageMyInfo->m_sEMail.Data()));
 
 	pui->pItem->myvalue = MessageMyInfo->m_nShared;
 	pui->pItem->mycol   = 5;
@@ -1108,9 +1122,9 @@ void DCClient::DC_Hello( CMessageHello * MessageHello )
 
 #ifndef WIN32
 		pm = *g_pConfig->GetUserIcon(FALSE,ecmNONE,euamNONE,eusUNKNOWN,eucvNONE);
-		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8(MessageHello->m_sNick.Data()), pm );
+		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii(MessageHello->m_sNick.Data()), pm );
 #else
-		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8(MessageHello->m_sNick.Data()) );
+		pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii(MessageHello->m_sNick.Data()) );
 #endif
 		pui->MyInfo.m_sNick = MessageHello->m_sNick;
 		pui->MyInfo.m_bOperator = FALSE;
@@ -1200,9 +1214,9 @@ void DCClient::DC_NickList( CMessageNickList * MessageNickList )
 	
 #ifndef WIN32
 				pm = *g_pConfig->GetUserIcon(FALSE,ecmNONE,euamNONE,eusUNKNOWN,eucvNONE);
-				pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8((*Nick).Data()), pm );
+				pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii((*Nick).Data()), pm );
 #else
-				pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8((*Nick).Data()) );
+				pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii((*Nick).Data()) );
 #endif
 				pui->pItem->mycol = 5;
 				pui->MyInfo.m_sNick = (*Nick);
@@ -1255,9 +1269,9 @@ void DCClient::DC_OpList( CMessageNickList * MessageOpList )
 
 #ifndef WIN32
 			pm = *g_pConfig->GetUserIcon(TRUE,ecmNONE,euamNONE,eusUNKNOWN,eucvNONE);
-			pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8((*Nick).Data()), pm );
+			pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii((*Nick).Data()), pm );
 #else
-			pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromUtf8((*Nick).Data()) );
+			pui->pItem = new DC_UserListItem( ListView_USERLIST, QString::fromAscii((*Nick).Data()) );
 #endif
 			pui->pItem->mycol = 5;
 			pui->MyInfo.m_sNick = (*Nick);
@@ -1330,7 +1344,7 @@ void DCClient::DC_PrivateChat( CMessagePrivateChat * msg, bool bLocal )
 		else
 		{
 			chat = new DCChat( m_pWorkspace, "chat", WDestructiveClose, this );
-			new QListViewItem(ListView_CHATUSERLIST,QString::fromUtf8(msg->m_sSrcNick.Data()));
+			new QListViewItem(ListView_CHATUSERLIST,QString::fromAscii(msg->m_sSrcNick.Data()));
 			TabWidget_CHAT->setTabLabel( TabWidget_CHAT->page(0), tr("Chat List")+" ("+QString().setNum(ListView_CHATUSERLIST->childCount())+")" );
 		}
 
@@ -1723,6 +1737,7 @@ void DCClient::slotRightButtonClickedUserList( QListViewItem *, const QPoint &,
 	{
 		DCMenuHandler::InsertMenu( m, emiKICK, UserList()->IsAdmin(GetNick()) && (numSelected > 0) );
 		DCMenuHandler::InsertMenu( m, emiFORCE_MOVE, UserList()->IsAdmin(GetNick()) && (numSelected > 0) );
+		DCMenuHandler::InsertMenu( m, emiGET_USER_IP, UserList()->IsAdmin(GetNick()) && (numSelected > 0) && GetSupportsUserIP2() );
 	}
 	
 	DCMenuHandler::InsertMenu( m, emiSEPARATOR );
@@ -1746,7 +1761,7 @@ void DCClient::slotRightButtonClickedUserList( QListViewItem *, const QPoint &,
 	{
 		for(ps=0;(ps=selitems.Next(ps)) != 0;)
 		{
-			DC_PrivateChat( QString::fromUtf8(ps->Data()), "", "", TRUE );
+			DC_PrivateChat( QString::fromAscii(ps->Data()), "", "", TRUE );
 		}
 	}
 	else if ( id == emiADD_FRIEND )
@@ -1871,6 +1886,13 @@ void DCClient::slotRightButtonClickedUserList( QListViewItem *, const QPoint &,
 			OPForceMove( ps->Data(), message, host );
 		}
 	}
+	else if ( id == emiGET_USER_IP )
+	{
+		for( ps=0; (ps=selitems.Next(ps)) != 0; )
+		{
+			SendString( CString("$UserIP ") + ps->Data() + CString("|") );
+		}
+	}
 	else if ( id == emiRELOAD_USERLIST )
 	{
 		RequestNickList();
@@ -2016,7 +2038,7 @@ void DCClient::removeCompleteNick( QString nick )
 /** */
 QString DCClient::findNick( QString part, uint which )
 {
-	QStrList matches;
+	QStringList matches;
 	QString lpart = part.lower();
 	
 	for (QStringList::ConstIterator it = m_completeNicks.begin(); it != m_completeNicks.end(); ++it)
@@ -2045,7 +2067,7 @@ QString DCClient::findNick( QString part, uint which )
 	if(matches.count() > 0)
 	{
 		if(which < matches.count())
-			return matches.at(which);
+			return *(matches.at(which));
 		else
 			return QString::null;
 	}
@@ -2105,6 +2127,9 @@ QString DCClient::replaceCommandTags(QString command, QString remotenick)
 		usercommand.replace( "%[userDE]", item->text(1) );
 		usercommand.replace( "%[description]", item->text(1) );
 		
+		usercommand.replace( "%[userSS]", QString().setNum(((DC_UserListItem*)item)->myvalue) );
+		usercommand.replace( "%[share]", QString().setNum(((DC_UserListItem*)item)->myvalue) );
+		
 		usercommand.replace( "%[userSSshort]", item->text(5) );
 		usercommand.replace( "%[shareshort]", item->text(5) );
 		
