@@ -75,11 +75,13 @@
 #define XML_SOUND_FILE_SEND		"soundfilesend"
 #define XML_SOUND_FILE_RECEIVE		"soundfilereceive"
 #define XML_SOUND_FILE_FIRSTRECEIVE	"soundfilefirstreceive"
+#define XML_SOUND_FILE_NICK_MENTIONED	"soundnickmentioned"
 #define XML_SOUND_ENABLED_CONNECT	"soundenabledconnect"
 #define XML_SOUND_ENABLED_DISCONNECT	"soundenableddisconnect"
 #define XML_SOUND_ENABLED_SEND		"soundenabledsend"
 #define XML_SOUND_ENABLED_RECEIVE	"soundenabledreceive"
 #define XML_SOUND_ENABLED_FIRSTRECEIVE	"soundenabledfirstreceive"
+#define XML_SOUND_ENABLED_NICK_MENTIONED	"soundenablednickmentioned"
 #define XML_SOUND_DISABLED		"sounddisabled"
 #define XML_SOUND_DISABLED_AWAY		"sounddisabledaway"
 #define XML_TIMESTAMP_PRIVATECHAT	"timestampprivatechat"
@@ -98,6 +100,7 @@
 #define XML_CHATMAXPARAGRAPH		"chatmaxparagraph"
 #define XML_DEFAULTFBREMOTEENCODING	"defaultfilelistremoteencoding"
 #define XML_VALKNUT_DATA_PATH		"valknutdatapath"
+#define XML_QMAINWINDOW_STATE		"qmainwindowstate"
 
 #define XML_APP_ICON_THEME		"appicontheme"
 #define XML_EMOTICON_THEME		"emoticontheme"
@@ -214,6 +217,7 @@
 
 #define XML_FOLDERS_RIGHT_PANE		"folders_in_right_pane"
 #define XML_SIZES_IN_LEFT_PANE		"sizes_in_left_pane"
+#define XML_FOLDERS_RIGHT_PANE_ON_TOP	"folders_in_right_pane_on_top"
 
 DCConfig * g_pConfig = 0;
 
@@ -239,6 +243,7 @@ DCConfig::DCConfig( CString configpath ) : CConfig(configpath)
 	sSoundFileSend		= "";
 	sSoundFileReceive	= "";
 	sSoundFileFirstReceive	= "";
+	sSoundFileNickMentioned = "";
 
 	bSoundDisabled		= TRUE;
 	bSoundDisabledAway	= TRUE;
@@ -248,6 +253,7 @@ DCConfig::DCConfig( CString configpath ) : CConfig(configpath)
 	bSoundEnabledSend	= TRUE;
 	bSoundEnabledReceive	= TRUE;
 	bSoundEnabledFirstReceive = TRUE;
+	bSoundEnabledNickMentioned = TRUE;
 
 	bEnableEmoticons        = TRUE;
 	bTimeStampPrivateChat	= TRUE;
@@ -372,6 +378,9 @@ DCConfig::DCConfig( CString configpath ) : CConfig(configpath)
 	
 	m_bFoldersInRightPane = FALSE;
 	m_bFolderSizesInLeftPane = TRUE;
+	m_bFoldersInRightPaneOnTop = FALSE;
+
+	m_sQT4MainWindowState = "";
 
 #if defined(Q_OS_MACX) 
 	CFURLRef pluginRef = CFBundleCopyBundleURL(CFBundleGetMainBundle()); 
@@ -491,6 +500,8 @@ void DCConfig::ParseDCGuiConfig( xmlNodePtr node )
 					sSoundFileReceive = xml.content(n2);
 				else if ( xml_name == XML_SOUND_FILE_FIRSTRECEIVE )
 					sSoundFileFirstReceive = xml.content(n2);
+				else if ( xml_name == XML_SOUND_FILE_NICK_MENTIONED )
+					sSoundFileNickMentioned = xml.content(n2);
 				else if ( xml_name == XML_EXTERNAL_SOUND_PLAYER )
 					bExternalSoundPlayer = xml.getBoolChild(n2);
 				else if ( xml_name == XML_EXTERNAL_PLAYER )
@@ -509,6 +520,8 @@ void DCConfig::ParseDCGuiConfig( xmlNodePtr node )
 					bSoundEnabledReceive = xml.getBoolChild(n2);
 				else if ( xml_name == XML_SOUND_ENABLED_FIRSTRECEIVE )
 					bSoundEnabledFirstReceive = xml.getBoolChild(n2);
+				else if ( xml_name == XML_SOUND_ENABLED_NICK_MENTIONED )
+					bSoundEnabledNickMentioned = xml.getBoolChild(n2);
 				else if ( xml_name == XML_TIMESTAMP_PRIVATECHAT )
 					bTimeStampPrivateChat = xml.getBoolChild(n2);
 				else if ( xml_name == XML_TIMESTAMP_HUBCHAT )
@@ -741,10 +754,14 @@ void DCConfig::ParseDCGuiConfig( xmlNodePtr node )
 					m_sUserListIconTheme = xml.content(n2).Data();
 				else if ( xml_name == XML_FILELIST_NAMING_SCHEME )
 					m_nFilelistNamingSchemeVersion = xml.content(n2).asINT();
+				else if ( xml_name == XML_QMAINWINDOW_STATE )
+					m_sQT4MainWindowState = xml.content(n2).Data();
 				else if ( xml_name == XML_FOLDERS_RIGHT_PANE )
 					SetFoldersInRightPane( xml.getBoolChild(n2) );
 				else if ( xml_name == XML_SIZES_IN_LEFT_PANE )
 					SetFolderSizesInLeftPane( xml.getBoolChild(n2) );
+				else if ( xml_name == XML_FOLDERS_RIGHT_PANE_ON_TOP )
+					SetFoldersInRightPaneOnTop( xml.getBoolChild(n2) );
 			}
 		}
 	}
@@ -795,6 +812,14 @@ int DCConfig::LoadDCGui()
 
 	InitMimeSourceFactory();
 
+	// check datapath exists
+	QDir dir( GetValknutDataPath() );
+	if ( !dir.exists() )
+	{
+		printf("Data path specified does not exist, resetting.\n");
+		SetValknutDataPath(VALKNUT_DATAPATH);
+	}
+
 	return err;
 }
 
@@ -861,8 +886,10 @@ int DCConfig::SaveDCGui()
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_ENABLETRAY, m_bEnableTray );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_QUERYONEXIT, bQueryOnExit );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_QUERYONFILEDELETE, bQueryOnFileDelete );
+	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_QMAINWINDOW_STATE, m_sQT4MainWindowState.ascii() );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_FOLDERS_RIGHT_PANE, m_bFoldersInRightPane );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SIZES_IN_LEFT_PANE, m_bFolderSizesInLeftPane );
+	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_FOLDERS_RIGHT_PANE_ON_TOP, m_bFoldersInRightPaneOnTop );
 
 	// sound settings
 	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_SOUND_FILE_CONNECT, sSoundFileConnect );
@@ -870,12 +897,14 @@ int DCConfig::SaveDCGui()
 	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_SOUND_FILE_SEND, sSoundFileSend );
 	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_SOUND_FILE_RECEIVE, sSoundFileReceive );
 	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_SOUND_FILE_FIRSTRECEIVE, sSoundFileFirstReceive );
+	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_SOUND_FILE_NICK_MENTIONED, sSoundFileNickMentioned );
 	xml.xmlNewStringChild( node, 0, (const xmlChar*)XML_EXTERNAL_PLAYER, sExternalPlayer );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_CONNECT, bSoundEnabledConnect );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_DISCONNECT, bSoundEnabledDisconnect );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_SEND, bSoundEnabledSend );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_RECEIVE, bSoundEnabledReceive );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_FIRSTRECEIVE, bSoundEnabledFirstReceive );
+	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_ENABLED_NICK_MENTIONED, bSoundEnabledNickMentioned );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_EXTERNAL_SOUND_PLAYER, bExternalSoundPlayer );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_DISABLED, bSoundDisabled );
 	xml.xmlNewBoolChild( node, 0, (const xmlChar*)XML_SOUND_DISABLED_AWAY, bSoundDisabledAway );
@@ -1342,6 +1371,9 @@ CString DCConfig::GetSoundFile( eUserSound usersound )
 		case eusFIRSTRECEIVE:
 			s = sSoundFileFirstReceive;
 			break;
+		case eusNICKMENTIONED:
+			s = sSoundFileNickMentioned;
+			break;
 		default:
 			s = "";
 			break;
@@ -1370,6 +1402,9 @@ void DCConfig::SetSoundFile( eUserSound usersound, CString soundfile )
 		case eusFIRSTRECEIVE:
 			sSoundFileFirstReceive = soundfile;
 			break;
+		case eusNICKMENTIONED:
+			sSoundFileNickMentioned = soundfile;
+			break;
 		default:
 			break;
 	}
@@ -1397,6 +1432,9 @@ bool DCConfig::GetSoundEnabled( eUserSound usersound )
 		case eusFIRSTRECEIVE:
 			b = bSoundEnabledFirstReceive;
 			break;
+		case eusNICKMENTIONED:
+			b = bSoundEnabledNickMentioned;
+			break;
 		default:
 			b = FALSE;
 			break;
@@ -1425,6 +1463,9 @@ void DCConfig::SetSoundEnabled( eUserSound usersound, bool enabled )
 		case eusFIRSTRECEIVE:
 			bSoundEnabledFirstReceive = enabled;
 			break;
+		case eusNICKMENTIONED:
+			bSoundEnabledNickMentioned = enabled;
+			break;
 		default:
 			break;
 	}
@@ -1467,6 +1508,10 @@ void DCConfig::PlaySound( eUserSound usersound )
 			if ( bSoundEnabledFirstReceive )
 				s = sSoundFileFirstReceive;
 			break;
+		case eusNICKMENTIONED:
+			if ( bSoundEnabledNickMentioned )
+				s = sSoundFileNickMentioned;
+			break;
 		default:
 			break;
 	}
@@ -1645,7 +1690,7 @@ bool DCConfig::InitMimeSourceFactory()
 	if ( xml.ParseFile(s+"emoticons.xml") == FALSE )
 	{
 		// get global icons
-		s = (GetValknutDataPath()+DIRSEPARATOR+"icons"+DIRSEPARATOR+"emot"+DIRSEPARATOR+"default"+DIRSEPARATOR).ascii();
+		s = (GetValknutDataPath()+DIRSEPARATOR+"icons"+DIRSEPARATOR+"emot"+DIRSEPARATOR+GetEmoticonTheme()+DIRSEPARATOR).ascii();
 
 		if ( xml.ParseFile(s+"emoticons.xml") == FALSE )
 		{
