@@ -56,7 +56,8 @@ typedef enum eUserSound {
 	eusDISCONNECT,
 	eusSEND,
 	eusRECEIVE,
-	eusFIRSTRECEIVE
+	eusFIRSTRECEIVE,
+	eusNICKMENTIONED
 } eUserSound;
 
 /** */
@@ -586,6 +587,10 @@ public:
 	bool GetFolderSizesInLeftPane() const;
 	/** Set show subfolder sizes in left pane of filelist browser */
 	void SetFolderSizesInLeftPane( bool b );
+	/** Get sort folders in right pane on top */
+	bool GetFoldersInRightPaneOnTop() const;
+	/** Set sort folders in right pane on top */
+	void SetFoldersInRightPaneOnTop( bool b );
 	
 private:
 	/** */
@@ -645,6 +650,8 @@ private:
 	/** */
 	bool bSoundEnabledFirstReceive;
 	/** */
+	bool bSoundEnabledNickMentioned;
+	/** */
 	bool bExternalSoundPlayer;
 	/** */
 	CString sExternalPlayer;
@@ -658,6 +665,8 @@ private:
 	CString sSoundFileReceive;
 	/** first receive sound file */
 	CString sSoundFileFirstReceive;
+	/** nick said in public chat */
+	CString sSoundFileNickMentioned;
 
 	/** */
 	bool bEnableEmoticons;
@@ -878,10 +887,15 @@ private:
 	  */
 	int m_nFilelistNamingSchemeVersion;
 	
+	/** Saved QT4 QMainWindow state */
+	QString m_sQT4MainWindowState;
+	
 	/** Show folders in right pane of filelist browser? */
 	bool m_bFoldersInRightPane;
 	/** Show subfolder sizes in left pane of filelist browser? */
 	bool m_bFolderSizesInLeftPane;
+	/** Sort folders in right pane on top */
+	bool m_bFoldersInRightPaneOnTop;
 };
 
 /** global config */
@@ -1217,4 +1231,10 @@ inline bool DCConfig::GetFolderSizesInLeftPane() const
 /** */
 inline void DCConfig::SetFolderSizesInLeftPane( bool b )
 { m_bFolderSizesInLeftPane = b; }
+/** */
+inline bool DCConfig::GetFoldersInRightPaneOnTop() const
+{ return m_bFoldersInRightPaneOnTop; }
+/** */
+inline void DCConfig::SetFoldersInRightPaneOnTop( bool b )
+{ m_bFoldersInRightPaneOnTop = b; }
 #endif
