@@ -42,6 +42,9 @@
 #include <dclib/core/cxml.h>
 #include <dclib/cutils.h>
 
+// for file type icons
+#include <dclib/cfilemanager.h>
+
 /** */
 DCFileBrowser::DCFileBrowser( QWidget* parent, const char *name, int wflags, bool viewonly )
 	: DCDialogFileBrowser( parent, name, wflags )
@@ -57,6 +60,11 @@ DCFileBrowser::DCFileBrowser( QWidget* parent, const char *name, int wflags, boo
 	ListView_FILES->setColumnWidthMode( 3, QListView::Maximum );
 	ListView_FILES->setColumnWidthMode( 4, QListView::Maximum );
 	
+	// set right alignment on size columns
+	ListView_DIRECTORY->setColumnAlignment( 1, Qt::AlignRight );
+	ListView_FILES->setColumnAlignment( 1, Qt::AlignRight );
+	ListView_FILES->setColumnAlignment( 2, Qt::AlignRight );
+	
 	// hide the column header - only if not using size column
 	if ( g_pConfig->GetFolderSizesInLeftPane() == FALSE )
 	{
@@ -261,7 +269,7 @@ void DCFileBrowser::slotFileSave()
 			s += m_sList;
 		}
 		
-		stream.writeRawBytes(s.ascii(),s.length());
+		stream.writeRawBytes(s.ascii(),strlen(s.ascii()));
 
         	file.close();
 	}
@@ -301,17 +309,53 @@ void DCFileBrowser::slotCurrentChangedDirectory()
 			if ( s != "" )
 				s += " " + tr("file");
 
-			DC_QListViewItem *item1 = new DC_QListViewItem(ListView_FILES);
+			DC_FBListViewItem *item1 = new DC_FBListViewItem(ListView_FILES);
 			item1->myvalue = FileItem->m_sSize.toULongLong();
 			item1->mycol   = 1;
+			item1->m_bSortTop = FALSE;
 			
 			if ( FileItem->m_bIsDir )
 			{
 				s = tr("Folder");
 				item1->setPixmap(0,m_FolderPixmap);
+				
+				if ( g_pConfig->GetFoldersInRightPaneOnTop() == TRUE )
+				{
+					item1->m_bSortTop = TRUE;
+				}
 			}
 			else
 			{
+				eFileTypes type = CFileManager::Instance()->GetFileType(FileItem->m_sName.ascii());
+				QPixmap icon;
+				
+				switch (type)
+				{
+					case eftMP3:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_MP3);
+						break;
+					case eftARCHIVE:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_ARCHIVE);
+						break;
+					case eftDOCUMENT:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_DOCUMENT);
+						break;
+					case eftAPPLICATION:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_APPLICATION);
+						break;
+					case eftPICTURE:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_PICTURE);
+						break;
+					case eftVIDEO:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_VIDEO);
+						break;
+					default:
+						icon = g_pIconLoader->GetPixmap(eiFILETYPE_UNKNOWN);
+						break;
+				}
+				
+				item1->setPixmap( 0, icon );
+				
 				items++;
 			}
 
