@@ -1145,6 +1145,7 @@ bool DCGuiApp::eventFilter(QObject* object, QEvent* event)
 			if ( id == emiRESET )
 			{
 				CSocket::m_Traffic.ResetTraffic();
+				g_pConfig->ResetSessionStats();
 				statusTRLabel->setText("");
 			}
 		}
@@ -1579,11 +1580,50 @@ void DCGuiApp::slotHelpAbout()
 {
 	QString s;
 	DCDialogAbout * dlg;
-
+	ulonglong up = CSocket::m_Traffic.GetTraffic(ettTX);
+	ulonglong down = CSocket::m_Traffic.GetTraffic(ettRX);
+	float ratio = 0;
+	
+	if ( down > 0 )
+	{
+		ratio = (double) up / (double) down;
+	}
+	
 	dlg = new DCDialogAbout(this);
+	
+	s  = dlg->TextLabel2->text();
+	s += "\n\n\n";
+	s += tr("Ratio: Overall: ");
+	s += QString().setNum( ratio, 'f', 2 );
+	s += tr(" (Up: ");
+	s += CUtils::GetSizeString( up, g_pConfig->GetUnit() ).Data();
+	s += tr(", Down: ");
+	s += CUtils::GetSizeString( down, g_pConfig->GetUnit() ).Data();
+	s += tr(")\nThis session: ");
+	
+	up -= g_pConfig->GetStartUploaded();
+	down -= g_pConfig->GetStartDownloaded();
+	
+	if ( down > 0 )
+	{
+		ratio = (double) up / (double) down;
+	}
+	else
+	{
+		ratio = 0;
+	}
+	
+	s += QString().setNum( ratio, 'f', 2 );
+	s += tr(" (Up: ");
+	s += CUtils::GetSizeString( up, g_pConfig->GetUnit() ).Data();
+	s += tr(", Down: ");
+	s += CUtils::GetSizeString( down, g_pConfig->GetUnit() ).Data();
+	s += ")";
 
 	dlg->TextLabel_VERSION->setText( "Valknut " VERSION );
 	dlg->PixmapLabel_ICON->setPixmap( g_pIconLoader->GetPixmap(eiGLOBE) );
+	
+	dlg->TextLabel2->setText( s );
 
 	dlg->TextEdit_AUTHORS->append(g_sAboutAuthors);
 	dlg->TextEdit_AUTHORS->setCursorPosition(0,0);
