@@ -573,9 +573,9 @@ void DCHubListManager::ShowPublicHubList()
 			item->myvalue = hubitem->m_sUserCount.asULL();
 			item->mycol = 3;
 
-			item->setText(0,QString::fromUtf8(hubitem->m_sName.Data()));
-			item->setText(1,QString::fromUtf8(hubitem->m_sHost.Data()));
-			item->setText(2,QString::fromUtf8(hubitem->m_sDescription.Data()));
+			item->setText(0,QString::fromAscii(hubitem->m_sName.Data()));
+			item->setText(1,QString::fromAscii(hubitem->m_sHost.Data()));
+			item->setText(2,QString::fromAscii(hubitem->m_sDescription.Data()));
 			item->setText(3,hubitem->m_sUserCount.Data());
 		}
 	}
