@@ -65,6 +65,9 @@
 #include <dclib/core/cxml.h>
 #include <dclib/chttp.h>
 
+// for file type icons
+#include <dclib/cfilemanager.h>
+
 /* column numbers for the search results listview */
 #define RESULTS_COLUMN_FILE		0
 #define RESULTS_COLUMN_SIZE		1
@@ -99,6 +102,11 @@ DCHubSearch::DCHubSearch(QWidget* parent, const char *name, int wflags) : DCDial
 		ListView_SEARCHRESULTUSER->setColumnWidthMode( idx, QListView::Manual );
 	}
 
+	// right align numeric columns
+	ListView_SEARCHRESULT->setColumnAlignment( RESULTS_COLUMN_SIZE, Qt::AlignRight );
+	ListView_SEARCHRESULT->setColumnAlignment( RESULTS_COLUMN_FREESLOTS, Qt::AlignRight );
+	ListView_SEARCHRESULT->setColumnAlignment( RESULTS_COLUMN_TOTALSLOTS, Qt::AlignRight );
+
 	m_pMessageList      = new CList<CObject>();
 	m_pSearchResultList = new CList<CObject>();
 	m_pSearchQueryList  = 0;
@@ -724,21 +732,53 @@ bool DCHubSearch::AddSearchResult( CMessageSearchResult * MessageSearchResult, D
 	item->myvalue = MessageSearchResult->m_nSize;
 	item->mycol   = RESULTS_COLUMN_SIZE;
 
-	item->setText(RESULTS_COLUMN_FILE,QString::fromUtf8(sname.Data()));
+	item->setText(RESULTS_COLUMN_FILE,QString::fromAscii(sname.Data()));
 	if (MessageSearchResult->m_bFolder)
 	{
 		item->setText(RESULTS_COLUMN_SIZE,tr("Folder"));
+		
+		item->setPixmap(RESULTS_COLUMN_FILE,g_pIconLoader->GetPixmap(eiFOLDER_BLUE));
 	}
 	else
 	{
 		item->setText(RESULTS_COLUMN_SIZE,CUtils::GetSizeString(MessageSearchResult->m_nSize,g_pConfig->GetUnit()).Data());
+		
+		eFileTypes type = CFileManager::Instance()->GetFileType(sname);
+		QPixmap icon;
+		
+		switch (type)
+		{
+			case eftMP3:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_MP3);
+				break;
+			case eftARCHIVE:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_ARCHIVE);
+				break;
+			case eftDOCUMENT:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_DOCUMENT);
+				break;
+			case eftAPPLICATION:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_APPLICATION);
+				break;
+			case eftPICTURE:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_PICTURE);
+				break;
+			case eftVIDEO:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_VIDEO);
+				break;
+			default:
+				icon = g_pIconLoader->GetPixmap(eiFILETYPE_UNKNOWN);
+				break;
+		}
+		
+		item->setPixmap(RESULTS_COLUMN_FILE,icon);
 	}
 	item->setText(RESULTS_COLUMN_TTH,MessageSearchResult->m_sHash.Data());
-	item->setText(RESULTS_COLUMN_NICK,QString::fromUtf8(MessageSearchResult->m_sNick.Data()));
+	item->setText(RESULTS_COLUMN_NICK,QString::fromAscii(MessageSearchResult->m_sNick.Data()));
 	item->setText(RESULTS_COLUMN_FREESLOTS,QString().setNum(MessageSearchResult->m_nFreeSlot));
 	item->setText(RESULTS_COLUMN_TOTALSLOTS,QString().setNum(MessageSearchResult->m_nMaxSlot));
-	item->setText(RESULTS_COLUMN_HUB,QString::fromUtf8(MessageSearchResult->m_sHubName.Data()));
-	item->setText(RESULTS_COLUMN_PATH,QString::fromUtf8(spath.Data()));
+	item->setText(RESULTS_COLUMN_HUB,QString::fromAscii(MessageSearchResult->m_sHubName.Data()));
+	item->setText(RESULTS_COLUMN_PATH,QString::fromAscii(spath.Data()));
 	item->setText(RESULTS_COLUMN_HOST,MessageSearchResult->m_sHubHost.Data());
 
 	item->setVisible(visible);
@@ -1525,9 +1565,9 @@ void DCHubSearch::slotRightButtonClickedSearchResult( QListViewItem * /*item*/,
 			text += "magnet:?xt=urn:tree:tiger:";
 			text += curitem->text(2).mid(4);
 			
-			// cannot do size since no exact size column in search results dialog
-			//text += "&xl=";
-			//text += curitem->text();
+			// get size from myvalue used for numeric sorting
+			text += "&xl=";
+			text += QString().setNum(((DC_QListViewItem*)curitem)->myvalue);
 			
 			text += "&dn=";
 			QString filename = curitem->text(0);
