@@ -143,6 +143,14 @@ bool DCIconLoader::Load()
 	m_PixmapMap[eiFLAG_RUSSIA] = LoadPixmap("flag_russia.xpm");
 	m_PixmapMap[eiFLAG_SLOVAK] = LoadPixmap("flag_slovak.xpm");
 	
+	m_PixmapMap[eiFILETYPE_MP3] = LoadPixmap("filetype-audio.xpm");
+	m_PixmapMap[eiFILETYPE_ARCHIVE] = LoadPixmap("filetype-archive.xpm");
+	m_PixmapMap[eiFILETYPE_DOCUMENT] = LoadPixmap("filetype-document.xpm");
+	m_PixmapMap[eiFILETYPE_APPLICATION] = LoadPixmap("filetype-application.xpm");
+	m_PixmapMap[eiFILETYPE_PICTURE] = LoadPixmap("filetype-picture.xpm");
+	m_PixmapMap[eiFILETYPE_VIDEO] = LoadPixmap("filetype-video.xpm");
+	m_PixmapMap[eiFILETYPE_UNKNOWN] = LoadPixmap("filetype-unknown.xpm");
+	
 	m_PixmapMap[eiUSERICONS] = LoadPixmap("usericons.xpm");
 	
 	return m_bError;
