@@ -99,7 +99,14 @@ typedef enum eIcons {
     eiFLAG_SWEDEN,
     eiFLAG_LATVIAN,
     eiFLAG_RUSSIA,
-    eiFLAG_SLOVAK
+    eiFLAG_SLOVAK,
+    eiFILETYPE_MP3,
+    eiFILETYPE_ARCHIVE,
+    eiFILETYPE_DOCUMENT,
+    eiFILETYPE_APPLICATION,
+    eiFILETYPE_PICTURE,
+    eiFILETYPE_VIDEO,
+    eiFILETYPE_UNKNOWN,
 } eIcons;
 
 class QPixmap;
