@@ -88,6 +88,10 @@ QPopupMenu * DCMenuHandler::_InsertMenu( QPopupMenu * popupmenu, eMenuItems menu
 				popupmenu->insertItem( QObject::tr("Force Move"), menuitems );
 				popupmenu->setItemEnabled( menuitems, enabled );
 				break;
+		case emiGET_USER_IP:
+				popupmenu->insertItem( QObject::tr("Get user IP"), menuitems );
+				popupmenu->setItemEnabled( menuitems, enabled );
+				break;
 		case emiUPDATE_USER:
 				popupmenu->insertItem( QIconSet( g_pIconLoader->GetPixmap(eiRELOAD) ), QObject::tr("Update User"), menuitems );
 				popupmenu->setItemEnabled( menuitems, enabled );
