@@ -137,6 +137,7 @@ void DCOptions::InitDocument()
 	ComboBox_DEFAULTRENCODING->insertItem("DEFAULT");
 	ComboBox_DEFAULTRENCODING->insertStringList(codecList);
 	
+	ComboBox_REMOTE_ENCODING->insertItem("None");
 	ComboBox_REMOTE_ENCODING->insertItem("UTF-8");
 	ComboBox_REMOTE_ENCODING->insertItem("WINDOWS-1252");
 	ComboBox_REMOTE_ENCODING->insertItem("WINDOWS-1251");
@@ -172,6 +173,9 @@ void DCOptions::InitDocument()
 	SpinBox_SMALLFILESIZE->setMaxValue(104857600);   // 100MiB
 	SpinBox_AUTORESPONSEDELAY->setMinValue(0);
 	SpinBox_AUTORESPONSEDELAY->setMaxValue(3600);
+	SpinBox_READFILEBUFFERSIZE->setMinValue(4096);		// 4KiB
+	SpinBox_READFILEBUFFERSIZE->setMaxValue(20971520);	// 20MiB
+	SpinBox_READFILEBUFFERSIZE->setLineStep(1024);
 
 	// set up icons theme lists
 	setupIconThemeComboBoxes();
@@ -239,7 +243,7 @@ void DCOptions::InitDocument()
 
 	connect( ToolButton_PHOTO, SIGNAL(clicked()), this, SLOT(slotChangePhoto()) );
 
-	connect( ListView_OPTIONTREE, SIGNAL(clicked( QListViewItem * )), this, SLOT(slotListViewOptionClicked( QListViewItem * )) );
+	connect( ListView_OPTIONTREE, SIGNAL(currentChanged( QListViewItem * )), this, SLOT(slotListViewOptionCurrentChanged( QListViewItem * )) );
 	
 	connect( listView_MENU_COMMANDS, SIGNAL(contextMenuRequested( QListViewItem *, const QPoint &, int )), this, SLOT(slotContextMenuUserMenuCommands(QListViewItem *, const QPoint &, int)));
 	listView_MENU_COMMANDS->setDefaultRenameAction( QListView::Accept );
@@ -258,12 +262,14 @@ void DCOptions::InitDocument()
 	connect( ToolButton_BROWSESOUNDFILESEND, SIGNAL(clicked()), this, SLOT(slotBrowseSoundFileSend()) );
 	connect( ToolButton_BROWSESOUNDFILERECEIVE, SIGNAL(clicked()), this, SLOT(slotBrowseSoundFileReceive()) );
 	connect( ToolButton_BROWSESOUNDFILEFIRSTRECEIVE, SIGNAL(clicked()), this, SLOT(slotBrowseSoundFileFirstReceive()) );
+	connect( ToolButton_BROWSESOUNDFILENICKMENTIONED, SIGNAL(clicked()), this, SLOT(slotBrowseSoundFileNickMentioned()) );
 
 	connect( ToolButton_PREVIEWSOUNDFILECONNECT, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileConnect()) );
 	connect( ToolButton_PREVIEWSOUNDFILEDISCONNECT, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileDisconnect()) );
 	connect( ToolButton_PREVIEWSOUNDFILESEND, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileSend()) );
 	connect( ToolButton_PREVIEWSOUNDFILERECEIVE, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileReceive()) );
 	connect( ToolButton_PREVIEWSOUNDFILEFIRSTRECEIVE, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileFirstReceive()) );
+	connect( ToolButton_PREVIEWSOUNDFILENICKMENTIONED, SIGNAL(clicked()), this, SLOT(slotPreviewSoundFileNickMentioned()) );
 
 	connect( ToolButton_BROWSESOUNDPLAYER, SIGNAL(clicked()), this, SLOT(slotBrowseSoundPlayer()) );
 
@@ -329,6 +335,7 @@ void DCOptions::InitDocument()
 	connect( CheckBox_SOUNDPLAYSEND, SIGNAL(clicked()), this, SLOT(slotSoundPlaySend()) );
 	connect( CheckBox_SOUNDPLAYRECEIVE, SIGNAL(clicked()), this, SLOT(slotSoundPlayRecieve()) );
 	connect( CheckBox_SOUNDPLAYFIRSTRECEIVE, SIGNAL(clicked()), this, SLOT(slotSoundPlayFirstReceive()) );
+	connect( CheckBox_SOUNDPLAYNICKMENTIONED, SIGNAL(clicked()), this, SLOT(slotSoundPlayNickMentioned()) );
 
 	connect( ToolButton_BROWSELOGFILE, SIGNAL(clicked()), this, SLOT(slotBrowseLogFile()) );
 	
@@ -759,6 +766,7 @@ void DCOptions::slotDisableSound()
 	CheckBox_SOUNDPLAYSEND->setEnabled(b);
 	CheckBox_SOUNDPLAYRECEIVE->setEnabled(b);
 	CheckBox_SOUNDPLAYFIRSTRECEIVE->setEnabled(b);
+	CheckBox_SOUNDPLAYNICKMENTIONED->setEnabled(b);
 	CheckBox_EXTERNALPLAYER->setEnabled(b);
 
 	if (!b) {
@@ -779,6 +787,9 @@ void DCOptions::slotDisableSound()
 		LineEdit_SOUNDFILEFIRSTRECEIVE->setEnabled(b);
 		ToolButton_BROWSESOUNDFILEFIRSTRECEIVE->setEnabled(b);
 		ToolButton_PREVIEWSOUNDFILEFIRSTRECEIVE->setEnabled(b);
+		LineEdit_SOUNDFILENICKMENTIONED->setEnabled(b);
+		ToolButton_BROWSESOUNDFILENICKMENTIONED->setEnabled(b);
+		ToolButton_PREVIEWSOUNDFILENICKMENTIONED->setEnabled(b);
 	} else {
 		slotExternalPlayer();
 		slotSoundPlayConnect();
@@ -787,6 +798,7 @@ void DCOptions::slotDisableSound()
 		slotSoundPlaySend();
 		slotSoundPlayRecieve();
 		slotSoundPlayFirstReceive();
+		slotSoundPlayNickMentioned();
 	}
 }
 
@@ -861,12 +873,24 @@ void DCOptions::slotSoundPlayFirstReceive()
 	ToolButton_PREVIEWSOUNDFILEFIRSTRECEIVE->setEnabled(b);
 }
 
+/** */
+void DCOptions::slotSoundPlayNickMentioned()
+{
+	bool b;
+	
+	b = CheckBox_SOUNDPLAYNICKMENTIONED->isChecked();
+	
+	LineEdit_SOUNDFILENICKMENTIONED->setEnabled(b);
+	ToolButton_BROWSESOUNDFILENICKMENTIONED->setEnabled(b);
+	ToolButton_PREVIEWSOUNDFILENICKMENTIONED->setEnabled(b);
+}
+
 /** */
 void DCOptions::slotBrowseSoundPlayer()
 {
 	QString file;
 
-	file = QFileDialog::getOpenFileName( "", "", this, "blf", tr("Select sound player") );
+	file = QFileDialog::getOpenFileName( LineEdit_EXTERNALPLAYER->text(), "", this, "blf", tr("Select sound player") );
 
 	if( file != "" )
 	{
@@ -879,7 +903,7 @@ void DCOptions::slotBrowseTransferCert()
 {
 	QString file;
 
-	file = QFileDialog::getOpenFileName( "", "", this, "blf", tr("Select transfer cert") );
+	file = QFileDialog::getOpenFileName( LineEdit_TRANSFERCERT->text(), "", this, "blf", tr("Select transfer cert") );
 
 	if( file != "" )
 	{
@@ -892,7 +916,7 @@ void DCOptions::slotBrowseTransferKey()
 {
 	QString file;
 
-	file = QFileDialog::getOpenFileName( "", "", this, "blf", tr("Select transfer key") );
+	file = QFileDialog::getOpenFileName( LineEdit_TRANSFERKEY->text(), "", this, "blf", tr("Select transfer key") );
 
 	if( file != "" )
 	{
@@ -905,7 +929,7 @@ void DCOptions::slotBrowseBrowser()
 {
 	QString file;
 
-	file = QFileDialog::getOpenFileName( "", "", this, "blf", tr("Select a browser") );
+	file = QFileDialog::getOpenFileName( LineEdit_BROWSER->text(), "", this, "blf", tr("Select a browser") );
 
 	if( file != "" )
 	{
@@ -918,12 +942,38 @@ void DCOptions::BrowseSoundFile( eUserSound usersound )
 {
 	QString file;
 	QString filter;
+	QString current;
 
 	filter = tr("au")        + " (*.au);;"  +
 		 tr("wav")       + " (*.wav);;" +
 		 tr("All Files") + " (*)";
 
-	file = QFileDialog::getOpenFileName( "", filter, this, "blf", tr("Select sound file") );
+	switch(usersound)
+	{
+		case eusCONNECT:
+			current = LineEdit_SOUNDFILECONNECT->text();
+			break;
+		case eusDISCONNECT:
+			current = LineEdit_SOUNDFILEDISCONNECT->text();
+			break;
+		case eusSEND:
+			current = LineEdit_SOUNDFILESEND->text();
+			break;
+		case eusRECEIVE:
+			current = LineEdit_SOUNDFILERECEIVE->text();
+			break;
+		case eusFIRSTRECEIVE:
+			current = LineEdit_SOUNDFILEFIRSTRECEIVE->text();
+			break;
+		case eusNICKMENTIONED:
+			current = LineEdit_SOUNDFILENICKMENTIONED->text();
+			break;
+		default:
+			current = "";
+			break;
+	}
+
+	file = QFileDialog::getOpenFileName( current, filter, this, "blf", tr("Select sound file") );
 
 	if( file != "" )
 	{
@@ -944,6 +994,9 @@ void DCOptions::BrowseSoundFile( eUserSound usersound )
 			case eusFIRSTRECEIVE:
 				LineEdit_SOUNDFILEFIRSTRECEIVE->setText(file);
 				break;
+			case eusNICKMENTIONED:
+				LineEdit_SOUNDFILENICKMENTIONED->setText(file);
+				break;
 			default:
 				break;
 		}
@@ -972,6 +1025,9 @@ void DCOptions::PreviewSoundFile( eUserSound usersound )
 		case eusFIRSTRECEIVE:
 			file = LineEdit_SOUNDFILEFIRSTRECEIVE->text();
 			break;
+		case eusNICKMENTIONED:
+			file = LineEdit_SOUNDFILENICKMENTIONED->text();
+			break;
 		default:
 			break;
 	}
@@ -984,7 +1040,7 @@ void DCOptions::slotBrowseDownloadFolder()
 {
 	QString dir;
 
-	dir = QFileDialog::getExistingDirectory ( "", this, "bdf", tr("Select download folder"), TRUE );
+	dir = QFileDialog::getExistingDirectory ( LineEdit_DOWNLOADFOLDER->text(), this, "bdf", tr("Select download folder"), TRUE );
 
 	if(dir!="")
 	{
@@ -997,7 +1053,7 @@ void DCOptions::slotBrowseDownloadFinishedFolder()
 {
 	QString dir;
 
-	dir = QFileDialog::getExistingDirectory ( "", this, "bdf", tr("Select download finished folder"), TRUE );
+	dir = QFileDialog::getExistingDirectory ( LineEdit_DOWNLOADFINISHEDFOLDER->text(), this, "bdf", tr("Select download finished folder"), TRUE );
 
 	if(dir!="")
 	{
@@ -1010,7 +1066,7 @@ void DCOptions::slotBrowseDataFolder()
 {
 	QString dir;
 
-	dir = QFileDialog::getExistingDirectory ( "", this, "bdf", tr("Select data folder"), TRUE );
+	dir = QFileDialog::getExistingDirectory ( LineEdit_DATAFOLDER->text(), this, "bdf", tr("Select data folder"), TRUE );
 
 	if( dir != "" )
 	{
@@ -1029,7 +1085,7 @@ void DCOptions::slotBrowseLogFile()
 {
 	QString logfile;
 
-	logfile = QFileDialog::getSaveFileName ( "", "", this, 0, tr("Select log file") );
+	logfile = QFileDialog::getSaveFileName ( LineEdit_LOGFILENAME->text(), "", this, 0, tr("Select log file") );
 
 	if( !logfile.isEmpty() )
 	{
@@ -1448,11 +1504,13 @@ void DCOptions::SetValues()
 	LineEdit_SOUNDFILESEND->setText( g_pConfig->GetSoundFile(eusSEND).Data() );
 	LineEdit_SOUNDFILERECEIVE->setText( g_pConfig->GetSoundFile(eusRECEIVE).Data() );
 	LineEdit_SOUNDFILEFIRSTRECEIVE->setText( g_pConfig->GetSoundFile(eusFIRSTRECEIVE).Data() );
+	LineEdit_SOUNDFILENICKMENTIONED->setText( g_pConfig->GetSoundFile(eusNICKMENTIONED).Data() );
 	CheckBox_SOUNDPLAYCONNECT->setChecked(g_pConfig->GetSoundEnabled(eusCONNECT));
 	CheckBox_SOUNDPLAYDISCONNECT->setChecked(g_pConfig->GetSoundEnabled(eusDISCONNECT));
 	CheckBox_SOUNDPLAYSEND->setChecked(g_pConfig->GetSoundEnabled(eusSEND));
 	CheckBox_SOUNDPLAYRECEIVE->setChecked(g_pConfig->GetSoundEnabled(eusRECEIVE));
 	CheckBox_SOUNDPLAYFIRSTRECEIVE->setChecked(g_pConfig->GetSoundEnabled(eusFIRSTRECEIVE));
+	CheckBox_SOUNDPLAYNICKMENTIONED->setChecked(g_pConfig->GetSoundEnabled(eusNICKMENTIONED));
 
 	// log
 	CheckBox_LOGFILE->setChecked(g_pConfig->GetLogFile());
@@ -1541,7 +1599,13 @@ void DCOptions::SetValues()
 	ComboBox_REMOTE_ENCODING->setCurrentText( g_pConfig->GetRemoteEncoding().Data() );
 	
 	CheckBox_FOLDERS_RIGHT_PANE->setChecked(g_pConfig->GetFoldersInRightPane());
+	CheckBox_FOLDERS_RIGHT_PANE_ON_TOP->setChecked(g_pConfig->GetFoldersInRightPaneOnTop());
 	CheckBox_SIZES_LEFT_PANE->setChecked(g_pConfig->GetFolderSizesInLeftPane());
+	
+	CheckBox_ENABLE_USERIP2->setChecked(g_pConfig->GetUserIP2Enabled());
+	CheckBox_ENABLE_ZLINE->setChecked(g_pConfig->GetZLineEnabled());
+	
+	SpinBox_READFILEBUFFERSIZE->setValue(g_pConfig->GetReadFileBufferSize());
 }
 
 /** */
@@ -1653,6 +1717,7 @@ void DCOptions::GetValues()
 	g_pConfig->SetSoundEnabled(eusSEND,CheckBox_SOUNDPLAYSEND->isChecked());
 	g_pConfig->SetSoundEnabled(eusRECEIVE,CheckBox_SOUNDPLAYRECEIVE->isChecked());
 	g_pConfig->SetSoundEnabled(eusFIRSTRECEIVE,CheckBox_SOUNDPLAYFIRSTRECEIVE->isChecked());
+	g_pConfig->SetSoundEnabled(eusNICKMENTIONED,CheckBox_SOUNDPLAYNICKMENTIONED->isChecked());
 
 	g_pConfig->SetExternalSoundPlayer(CheckBox_EXTERNALPLAYER->isChecked());
 	g_pConfig->SetExternalPlayer(LineEdit_EXTERNALPLAYER->text().ascii());
@@ -1661,6 +1726,7 @@ void DCOptions::GetValues()
 	g_pConfig->SetSoundFile( eusSEND, LineEdit_SOUNDFILESEND->text().ascii());
 	g_pConfig->SetSoundFile( eusRECEIVE, LineEdit_SOUNDFILERECEIVE->text().ascii());
 	g_pConfig->SetSoundFile( eusFIRSTRECEIVE, LineEdit_SOUNDFILEFIRSTRECEIVE->text().ascii());
+	g_pConfig->SetSoundFile( eusNICKMENTIONED, LineEdit_SOUNDFILENICKMENTIONED->text().ascii());
 
 	g_pConfig->SetAppFont(LineEdit_APPFONT->text().ascii());
 
@@ -1698,6 +1764,8 @@ void DCOptions::GetValues()
 	}
 	// reload icons with new theme
 	g_pIconLoader->Load();
+	// reload emoticons
+	g_pConfig->InitMimeSourceFactory();
 	
 	// log settings
 	g_pConfig->SetLogFile(CheckBox_LOGFILE->isChecked());
@@ -1797,8 +1865,23 @@ void DCOptions::GetValues()
 	
 	g_pConfig->SetRemoteEncoding(ComboBox_REMOTE_ENCODING->currentText().ascii());
 	
+	if ( ComboBox_REMOTE_ENCODING->currentText().lower() == "none" )
+	{
+		QTextCodec::setCodecForCStrings( 0 );
+	}
+	else
+	{
+		QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+	}
+	
 	g_pConfig->SetFoldersInRightPane(CheckBox_FOLDERS_RIGHT_PANE->isChecked());
+	g_pConfig->SetFoldersInRightPaneOnTop(CheckBox_FOLDERS_RIGHT_PANE_ON_TOP->isChecked());
 	g_pConfig->SetFolderSizesInLeftPane(CheckBox_SIZES_LEFT_PANE->isChecked());
+	
+	g_pConfig->SetUserIP2Enabled(CheckBox_ENABLE_USERIP2->isChecked());
+	g_pConfig->SetZLineEnabled(CheckBox_ENABLE_ZLINE->isChecked());
+	
+	g_pConfig->SetReadFileBufferSize(SpinBox_READFILEBUFFERSIZE->value());
 }
 
 /** */
@@ -1948,7 +2031,7 @@ void DCOptions::slotBrowseLanguageFile()
 {
 	QString file;
 
-	file = QFileDialog::getOpenFileName( "", "Language File (*.qm)", this, "blf", tr("Select language file") );
+	file = QFileDialog::getOpenFileName( LineEdit_LANGUAGEFILE->text(), "Language File (*.qm)", this, "blf", tr("Select language file") );
 
 	if( file != "" )
 	{
@@ -2107,7 +2190,7 @@ void DCOptions::slotRemoveHubListUrl()
 }
 
 /** */
-void DCOptions::slotListViewOptionClicked( QListViewItem * item )
+void DCOptions::slotListViewOptionCurrentChanged( QListViewItem * item )
 {
 	if ( item == plviDCGUI )
 	{
