@@ -125,6 +125,8 @@ private slots:
 	void slotBrowseSoundFileReceive();
 	/** */
 	void slotBrowseSoundFileFirstReceive();
+	/** */
+	void slotBrowseSoundFileNickMentioned();
 
 	/** */
 	void slotLogChatEnableLogging();
@@ -150,6 +152,8 @@ private slots:
 	/** */
 	void slotSoundPlayFirstReceive();
 	/** */
+	void slotSoundPlayNickMentioned();
+	/** */
 	void slotPreviewSoundFileConnect();
 	/** */
 	void slotPreviewSoundFileDisconnect();
@@ -159,6 +163,8 @@ private slots:
 	void slotPreviewSoundFileReceive();
 	/** */
 	void slotPreviewSoundFileFirstReceive();
+	/** */
+	void slotPreviewSoundFileNickMentioned();
 
 	/** */
 	void slotBrowseSoundPlayer();
@@ -221,7 +227,7 @@ private slots:
 	/** */
 	void slotBrowseBrowser();
 	/** */
-	void slotListViewOptionClicked( QListViewItem * item );
+	void slotListViewOptionCurrentChanged( QListViewItem * item );
 	/** */
 	void slotDoubleClickedChatColor(QListBoxItem *);
 	/** */
@@ -258,6 +264,9 @@ inline void DCOptions::slotBrowseSoundFileReceive()
 inline void DCOptions::slotBrowseSoundFileFirstReceive()
 { BrowseSoundFile(eusFIRSTRECEIVE); }
 /** */
+inline void DCOptions::slotBrowseSoundFileNickMentioned()
+{ BrowseSoundFile(eusNICKMENTIONED); }
+/** */
 inline void DCOptions::slotPreviewSoundFileConnect()
 { PreviewSoundFile(eusCONNECT); }
 /** */
@@ -272,5 +281,8 @@ inline void DCOptions::slotPreviewSoundFileReceive()
 /** */
 inline void DCOptions::slotPreviewSoundFileFirstReceive()
 { PreviewSoundFile(eusFIRSTRECEIVE); }
+/** */
+inline void DCOptions::slotPreviewSoundFileNickMentioned()
+{ PreviewSoundFile(eusNICKMENTIONED); }
 
 #endif
