@@ -32,6 +32,9 @@
 
 #include "dcspy.h"
 
+// for numeric sorted list view item
+#include "dcwidget.h"
+
 #include <dclib/cquerymanager.h>
 
 /** */
@@ -146,12 +149,23 @@ void DCSpy::DC_Search( CMessageSearch * MessageSearch )
 		
 		if((item = ListView_SPY->findItem(s,0)))
 		{
-			item->setText(1,(QString("%1").arg(item->text(1).toUInt()+1)).rightJustify(7, '0'));
+			DC_QListViewItem * myitem = (DC_QListViewItem*) item;
+			myitem->myvalue++;
+			item->setText(1,QString().setNum(myitem->myvalue));
 			item->setText(2,QTime::currentTime().toString("hh:mm:ss"));
 		}
 		else
 		{
-			ListView_SPY->insertItem(new QListViewItem(ListView_SPY,s,"0000001",QTime::currentTime().toString("hh:mm:ss")));
+			DC_QListViewItem * myitem = new DC_QListViewItem(ListView_SPY);
+			
+			myitem->myvalue = 1;
+			myitem->mycol = 1;
+			
+			myitem->setText(0,s);
+			myitem->setText(1,QString().setNum(myitem->myvalue));
+			myitem->setText(2,QTime::currentTime().toString("hh:mm:ss"));
+			
+			ListView_SPY->insertItem(myitem);
 		}
 	}
 }
