@@ -181,7 +181,8 @@ void DCTransferView::InitDocument()
 	// init log tab
 	QGridLayout * tll = new QGridLayout( Frame_LOG, 1, 1, 4, 4, "tabLayoutLog");
 	m_pTextEdit_LOG = new DCQTextEdit( Frame_LOG, "TextEdit_LOG" );
-	m_pTextEdit_LOG->setReadOnly( TRUE );
+	m_pTextEdit_LOG->setTextFormat( Qt::LogText );
+	m_pTextEdit_LOG->setMaxLogLines( 300 );
 	tll->addWidget( m_pTextEdit_LOG, 0, 0 );
 
 	// install event filters
@@ -538,15 +539,6 @@ void DCTransferView::MessageLog( CMessageLog * msg )
 		bscroll = FALSE;
 	}
 
-	if ( m_pTextEdit_LOG->paragraphs() > 300 )
-	{
-		m_pTextEdit_LOG->removeParagraph(0);
-		m_pTextEdit_LOG->removeParagraph(0);
-		m_pTextEdit_LOG->removeParagraph(0);
-		m_pTextEdit_LOG->removeParagraph(0);
-		m_pTextEdit_LOG->removeParagraph(0);
-	}
-
 	m_pTextEdit_LOG->append( QTime::currentTime().toString("[hh:mm:ss] ") + msg->sMessage.Data());
 
 	if ( bscroll )
@@ -631,21 +623,26 @@ void DCTransferView::MessageTransfer( CMessageDMTransferObject * msg )
 		{
 			case estTRANSFERDOWNLOAD:
 				TransferListItem->pItem->setPixmap(2,g_pIconLoader->GetPixmap(eiDOWN));
+				TransferListItem->pItem->setTransferState("d");
 				//TransferListItem->pItem->setText(3,tr("Download"));
 				break;
 			case estTRANSFERUPLOAD:
 				TransferListItem->pItem->setPixmap(2,g_pIconLoader->GetPixmap(eiUP));
+				TransferListItem->pItem->setTransferState("u");
 				//TransferListItem->pItem->setText(3,tr("Upload"));
 				break;
 			case estTRANSFERHANDSHAKE:
 				TransferListItem->pItem->setPixmap(2,g_pIconLoader->GetPixmap(eiBACK));
+				TransferListItem->pItem->setTransferState("h");
 				//TransferListItem->pItem->setText(3,tr("Handshake"));
 				break;
 			case estNONE:
 				//TransferListItem->pItem->setText(3,tr("Nothing"));
+				TransferListItem->pItem->setTransferState("n");
 				break;
 			default:
 				TransferListItem->pItem->setPixmap(2,g_pIconLoader->GetPixmap(eiHELP));
+				TransferListItem->pItem->setTransferState("q");
 				//TransferListItem->pItem->setText(3,tr("Unknown"));
 				break;
 		}
@@ -1557,8 +1554,7 @@ void DCTransferView::SearchFileClone(QString filename, ulonglong size)
 	while (searchtxt.contains(re_ext))
 	    searchtxt.replace(re_ext," ");
 
-	g_pHubSearch->Combobox_SEARCH->insertItem(searchtxt,0);
-	g_pHubSearch->Combobox_SEARCH->setCurrentItem(0);
+	g_pHubSearch->Combobox_SEARCH->setEditText(searchtxt);
 	g_pHubSearch->LineEdit_SEARCHSIZE->setText(CString().setNum(size).Data());
 	g_pHubSearch->ComboBox_SEARCHTYPE->setCurrentItem(1);
 	g_pHubSearch->ComboBox_SEARCHUNIT->setCurrentItem(0);
@@ -2030,6 +2026,8 @@ void DCTransferView::slotRightButtonClickedLocalFilesList( QListViewItem * item
 	ulonglong size;
 	CUserFileInfo UserFileInfo;
 	bool removetransfer = true;
+	DCFileChunkObject * pFileChunk;
+	bool fileHasTTH = false;
 
 	if( item == 0 )
 	{
@@ -2087,9 +2085,22 @@ void DCTransferView::slotRightButtonClickedLocalFilesList( QListViewItem * item
 		remotefile = "";
 	}
 
+	// check if the file has a TTH
+	if ( g_pTransferView )
+	{
+		if ( (pFileChunk=g_pTransferView->DLM_QueueGetFileChunk(localfile.ascii())) != 0 )
+		{
+			if ( pFileChunk->m_sHash != "")
+			{
+				fileHasTTH = true;
+			}
+		}
+	}
+
 	m = new QPopupMenu(this);
 
 	DCMenuHandler::InsertMenu( m, emiSEARCH_FILE_CLONE, (size > 0) );
+	DCMenuHandler::InsertMenu( m, emiSEARCH_FILE_CLONE_TTH, fileHasTTH );
 	DCMenuHandler::InsertMenu( m, emiSEPARATOR );
 	DCMenuHandler::InsertMenu( m, emiREMOVE_TRANSFER_QUEUE, removetransfer );
 	//DCMenuHandler::InsertMenu( m, emiREMOVE_TRANSFER_QUEUE_DISK, (removetransfer && FALSE) ); //(TransferItem.eState == etwsIDLE) );
@@ -2151,6 +2162,29 @@ void DCTransferView::slotRightButtonClickedLocalFilesList( QListViewItem * item
 		else
 			SearchFileClone(remotefile, size);
 	}
+	else if ( id == emiSEARCH_FILE_CLONE_TTH )
+	{
+		g_pHubSearch->Combobox_SEARCH->setEditText(pFileChunk->m_sHash.Data());
+		g_pHubSearch->LineEdit_SEARCHSIZE->setText("0");
+		g_pHubSearch->ComboBox_SEARCHTYPE->setCurrentItem(9);
+		g_pHubSearch->ComboBox_SEARCHUNIT->setCurrentItem(0);
+		g_pHubSearch->ComboBox_SEARCHLIMIT->setCurrentItem(0);
+		
+		if ( g_pHubSearch->isMinimized() )
+		{
+			g_pHubSearch->showNormal();
+		}
+		else if ( g_pHubSearch->isVisible()==FALSE )
+		{
+			g_pHubSearch->setEnabled(TRUE);
+			g_pHubSearch->show();
+		}
+
+		if ( g_pHubSearch->TabWidget_HUBSEARCH->isVisible()==FALSE )
+		{
+			g_pHubSearch->TabWidget_HUBSEARCH->show();
+		}
+	}
 }
 
 /** */
