@@ -119,9 +119,6 @@ int main(int argc, char *argv[])
 	// fix start path
 	CDir d;
 
-	// makes QString::ascii() return utf-8
-	QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
-
 	DCDebug::arg_0 = argv[0];
 
 	if ( d.IsFile( argv[0], FALSE ) )
@@ -140,6 +137,9 @@ int main(int argc, char *argv[])
 	SOCKSinit(argv[0]);
 #endif
 
+	// makes QString::ascii() return utf-8
+	QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+
 	// check xml version
 	LIBXML_TEST_VERSION;
 
@@ -330,6 +330,12 @@ int main(int argc, char *argv[])
 		ret = -1;
 	}
 	
+	// unset codec if necessary
+	if ( g_pConfig->GetRemoteEncoding().ToLower() == "none" )
+	{
+		QTextCodec::setCodecForCStrings( 0 );
+	}
+	
 	// needs to be done after config loading for icon themes
 	if ( g_pIconLoader->Load() )
 	{
