@@ -498,3 +498,20 @@ void DC_QProgressListItem::setTransferState( QString s )
 {
 	sTransferState = s;
 }
+
+/** sort top parts copied from DC_UserListItem */
+int DC_FBListViewItem::compare( QListViewItem * i, int col, bool ascending ) const
+{
+	if ( m_bSortTop && !((DC_FBListViewItem*)i)->m_bSortTop )
+	{
+		return ascending ? -1 : 1;
+	}
+	else if ( !m_bSortTop && ((DC_FBListViewItem*)i)->m_bSortTop )
+	{
+		return ascending ? 1 : -1;
+	}
+	else
+	{
+		return DC_QListViewItem::compare( i, col, ascending );
+	}
+}
