@@ -196,4 +196,20 @@ private:
 	QString sTransferState;
 };
 
+/** Filelist browser list view item */
+class DC_FBListViewItem: public DC_QListViewItem {
+public:
+	/** constructor with view parent */
+	DC_FBListViewItem( QListView * parent ) : DC_QListViewItem( parent ) { };
+	/** constructor with item parent */
+	DC_FBListViewItem( QListViewItem * parent ) : DC_QListViewItem( parent ) { } ;
+	/** destructor */
+	virtual ~DC_FBListViewItem() { };
+	
+	/** re-implemented to use sort top */
+	virtual int compare( QListViewItem * i, int col, bool ascending ) const;
+	/** should this be above other items? */
+	bool m_bSortTop;
+};
+
 #endif
